# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['WlanArgs', 'Wlan']

@pulumi.input_type
class WlanArgs:
    def __init__(__self__, *,
                 security: pulumi.Input[str],
                 user_group_id: pulumi.Input[str],
                 ap_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 hide_ssid: Optional[pulumi.Input[bool]] = None,
                 is_guest: Optional[pulumi.Input[bool]] = None,
                 l2_isolation: Optional[pulumi.Input[bool]] = None,
                 mac_filter_enabled: Optional[pulumi.Input[bool]] = None,
                 mac_filter_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 mac_filter_policy: Optional[pulumi.Input[str]] = None,
                 minimum_data_rate2g_kbps: Optional[pulumi.Input[int]] = None,
                 minimum_data_rate5g_kbps: Optional[pulumi.Input[int]] = None,
                 multicast_enhance: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_id: Optional[pulumi.Input[str]] = None,
                 no2ghz_oui: Optional[pulumi.Input[bool]] = None,
                 passphrase: Optional[pulumi.Input[str]] = None,
                 pmf_mode: Optional[pulumi.Input[str]] = None,
                 radius_profile_id: Optional[pulumi.Input[str]] = None,
                 schedules: Optional[pulumi.Input[Sequence[pulumi.Input['WlanScheduleArgs']]]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 uapsd: Optional[pulumi.Input[bool]] = None,
                 wlan_band: Optional[pulumi.Input[str]] = None,
                 wpa3_support: Optional[pulumi.Input[bool]] = None,
                 wpa3_transition: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a Wlan resource.
        :param pulumi.Input[str] security: The type of WiFi security for this network. Valid values are: `wpapsk`, `wpaeap`, and `open`.
        :param pulumi.Input[str] user_group_id: ID of the user group to use for this network.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] ap_group_ids: IDs of the AP groups to use for this network.
        :param pulumi.Input[bool] hide_ssid: Indicates whether or not to hide the SSID from broadcast.
        :param pulumi.Input[bool] is_guest: Indicates that this is a guest WLAN and should use guest behaviors.
        :param pulumi.Input[bool] l2_isolation: Isolates stations on layer 2 (ethernet) level Defaults to `false`.
        :param pulumi.Input[bool] mac_filter_enabled: Indicates whether or not the MAC filter is turned of for the network.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] mac_filter_lists: List of MAC addresses to filter (only valid if `mac_filter_enabled` is `true`).
        :param pulumi.Input[str] mac_filter_policy: MAC address filter policy (only valid if `mac_filter_enabled` is `true`). Defaults to `deny`.
        :param pulumi.Input[int] minimum_data_rate2g_kbps: Set minimum data rate control for 2G devices, in Kbps. Use `0` to disable minimum data rates. Valid values are: `1000`, `2000`, `5500`, `6000`, `9000`, `11000`, `12000`, `18000`, `24000`, `36000`, `48000`,  and `54000`.
        :param pulumi.Input[int] minimum_data_rate5g_kbps: Set minimum data rate control for 5G devices, in Kbps. Use `0` to disable minimum data rates. Valid values are: `6000`, `9000`, `12000`, `18000`, `24000`, `36000`, `48000`,  and `54000`.
        :param pulumi.Input[bool] multicast_enhance: Indicates whether or not Multicast Enhance is turned of for the network.
        :param pulumi.Input[str] name: The SSID of the network.
        :param pulumi.Input[str] network_id: ID of the network for this SSID
        :param pulumi.Input[bool] no2ghz_oui: Connect high performance clients to 5 GHz only Defaults to `true`.
        :param pulumi.Input[str] passphrase: The passphrase for the network, this is only required if `security` is not set to `open`.
        :param pulumi.Input[str] pmf_mode: Enable Protected Management Frames. This cannot be disabled if using WPA 3. Valid values are `required`, `optional` and `disabled`. Defaults to `disabled`.
        :param pulumi.Input[str] radius_profile_id: ID of the RADIUS profile to use when security `wpaeap`. You can query this via the `get_radius_profile` data source.
        :param pulumi.Input[Sequence[pulumi.Input['WlanScheduleArgs']]] schedules: Start and stop schedules for the WLAN
        :param pulumi.Input[str] site: The name of the site to associate the wlan with.
        :param pulumi.Input[bool] uapsd: Enable Unscheduled Automatic Power Save Delivery Defaults to `false`.
        :param pulumi.Input[str] wlan_band: Radio band your WiFi network will use.
        :param pulumi.Input[bool] wpa3_support: Enable WPA 3 support (security must be `wpapsk` and PMF must be turned on).
        :param pulumi.Input[bool] wpa3_transition: Enable WPA 3 and WPA 2 support (security must be `wpapsk` and `wpa3_support` must be true).
        """
        pulumi.set(__self__, "security", security)
        pulumi.set(__self__, "user_group_id", user_group_id)
        if ap_group_ids is not None:
            pulumi.set(__self__, "ap_group_ids", ap_group_ids)
        if hide_ssid is not None:
            pulumi.set(__self__, "hide_ssid", hide_ssid)
        if is_guest is not None:
            pulumi.set(__self__, "is_guest", is_guest)
        if l2_isolation is not None:
            pulumi.set(__self__, "l2_isolation", l2_isolation)
        if mac_filter_enabled is not None:
            pulumi.set(__self__, "mac_filter_enabled", mac_filter_enabled)
        if mac_filter_lists is not None:
            pulumi.set(__self__, "mac_filter_lists", mac_filter_lists)
        if mac_filter_policy is not None:
            pulumi.set(__self__, "mac_filter_policy", mac_filter_policy)
        if minimum_data_rate2g_kbps is not None:
            pulumi.set(__self__, "minimum_data_rate2g_kbps", minimum_data_rate2g_kbps)
        if minimum_data_rate5g_kbps is not None:
            pulumi.set(__self__, "minimum_data_rate5g_kbps", minimum_data_rate5g_kbps)
        if multicast_enhance is not None:
            pulumi.set(__self__, "multicast_enhance", multicast_enhance)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network_id is not None:
            pulumi.set(__self__, "network_id", network_id)
        if no2ghz_oui is not None:
            pulumi.set(__self__, "no2ghz_oui", no2ghz_oui)
        if passphrase is not None:
            pulumi.set(__self__, "passphrase", passphrase)
        if pmf_mode is not None:
            pulumi.set(__self__, "pmf_mode", pmf_mode)
        if radius_profile_id is not None:
            pulumi.set(__self__, "radius_profile_id", radius_profile_id)
        if schedules is not None:
            pulumi.set(__self__, "schedules", schedules)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if uapsd is not None:
            pulumi.set(__self__, "uapsd", uapsd)
        if wlan_band is not None:
            pulumi.set(__self__, "wlan_band", wlan_band)
        if wpa3_support is not None:
            pulumi.set(__self__, "wpa3_support", wpa3_support)
        if wpa3_transition is not None:
            pulumi.set(__self__, "wpa3_transition", wpa3_transition)

    @property
    @pulumi.getter
    def security(self) -> pulumi.Input[str]:
        """
        The type of WiFi security for this network. Valid values are: `wpapsk`, `wpaeap`, and `open`.
        """
        return pulumi.get(self, "security")

    @security.setter
    def security(self, value: pulumi.Input[str]):
        pulumi.set(self, "security", value)

    @property
    @pulumi.getter(name="userGroupId")
    def user_group_id(self) -> pulumi.Input[str]:
        """
        ID of the user group to use for this network.
        """
        return pulumi.get(self, "user_group_id")

    @user_group_id.setter
    def user_group_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "user_group_id", value)

    @property
    @pulumi.getter(name="apGroupIds")
    def ap_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        IDs of the AP groups to use for this network.
        """
        return pulumi.get(self, "ap_group_ids")

    @ap_group_ids.setter
    def ap_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "ap_group_ids", value)

    @property
    @pulumi.getter(name="hideSsid")
    def hide_ssid(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether or not to hide the SSID from broadcast.
        """
        return pulumi.get(self, "hide_ssid")

    @hide_ssid.setter
    def hide_ssid(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "hide_ssid", value)

    @property
    @pulumi.getter(name="isGuest")
    def is_guest(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates that this is a guest WLAN and should use guest behaviors.
        """
        return pulumi.get(self, "is_guest")

    @is_guest.setter
    def is_guest(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_guest", value)

    @property
    @pulumi.getter(name="l2Isolation")
    def l2_isolation(self) -> Optional[pulumi.Input[bool]]:
        """
        Isolates stations on layer 2 (ethernet) level Defaults to `false`.
        """
        return pulumi.get(self, "l2_isolation")

    @l2_isolation.setter
    def l2_isolation(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "l2_isolation", value)

    @property
    @pulumi.getter(name="macFilterEnabled")
    def mac_filter_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether or not the MAC filter is turned of for the network.
        """
        return pulumi.get(self, "mac_filter_enabled")

    @mac_filter_enabled.setter
    def mac_filter_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "mac_filter_enabled", value)

    @property
    @pulumi.getter(name="macFilterLists")
    def mac_filter_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of MAC addresses to filter (only valid if `mac_filter_enabled` is `true`).
        """
        return pulumi.get(self, "mac_filter_lists")

    @mac_filter_lists.setter
    def mac_filter_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "mac_filter_lists", value)

    @property
    @pulumi.getter(name="macFilterPolicy")
    def mac_filter_policy(self) -> Optional[pulumi.Input[str]]:
        """
        MAC address filter policy (only valid if `mac_filter_enabled` is `true`). Defaults to `deny`.
        """
        return pulumi.get(self, "mac_filter_policy")

    @mac_filter_policy.setter
    def mac_filter_policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mac_filter_policy", value)

    @property
    @pulumi.getter(name="minimumDataRate2gKbps")
    def minimum_data_rate2g_kbps(self) -> Optional[pulumi.Input[int]]:
        """
        Set minimum data rate control for 2G devices, in Kbps. Use `0` to disable minimum data rates. Valid values are: `1000`, `2000`, `5500`, `6000`, `9000`, `11000`, `12000`, `18000`, `24000`, `36000`, `48000`,  and `54000`.
        """
        return pulumi.get(self, "minimum_data_rate2g_kbps")

    @minimum_data_rate2g_kbps.setter
    def minimum_data_rate2g_kbps(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "minimum_data_rate2g_kbps", value)

    @property
    @pulumi.getter(name="minimumDataRate5gKbps")
    def minimum_data_rate5g_kbps(self) -> Optional[pulumi.Input[int]]:
        """
        Set minimum data rate control for 5G devices, in Kbps. Use `0` to disable minimum data rates. Valid values are: `6000`, `9000`, `12000`, `18000`, `24000`, `36000`, `48000`,  and `54000`.
        """
        return pulumi.get(self, "minimum_data_rate5g_kbps")

    @minimum_data_rate5g_kbps.setter
    def minimum_data_rate5g_kbps(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "minimum_data_rate5g_kbps", value)

    @property
    @pulumi.getter(name="multicastEnhance")
    def multicast_enhance(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether or not Multicast Enhance is turned of for the network.
        """
        return pulumi.get(self, "multicast_enhance")

    @multicast_enhance.setter
    def multicast_enhance(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "multicast_enhance", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The SSID of the network.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the network for this SSID
        """
        return pulumi.get(self, "network_id")

    @network_id.setter
    def network_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "network_id", value)

    @property
    @pulumi.getter(name="no2ghzOui")
    def no2ghz_oui(self) -> Optional[pulumi.Input[bool]]:
        """
        Connect high performance clients to 5 GHz only Defaults to `true`.
        """
        return pulumi.get(self, "no2ghz_oui")

    @no2ghz_oui.setter
    def no2ghz_oui(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "no2ghz_oui", value)

    @property
    @pulumi.getter
    def passphrase(self) -> Optional[pulumi.Input[str]]:
        """
        The passphrase for the network, this is only required if `security` is not set to `open`.
        """
        return pulumi.get(self, "passphrase")

    @passphrase.setter
    def passphrase(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "passphrase", value)

    @property
    @pulumi.getter(name="pmfMode")
    def pmf_mode(self) -> Optional[pulumi.Input[str]]:
        """
        Enable Protected Management Frames. This cannot be disabled if using WPA 3. Valid values are `required`, `optional` and `disabled`. Defaults to `disabled`.
        """
        return pulumi.get(self, "pmf_mode")

    @pmf_mode.setter
    def pmf_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pmf_mode", value)

    @property
    @pulumi.getter(name="radiusProfileId")
    def radius_profile_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the RADIUS profile to use when security `wpaeap`. You can query this via the `get_radius_profile` data source.
        """
        return pulumi.get(self, "radius_profile_id")

    @radius_profile_id.setter
    def radius_profile_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "radius_profile_id", value)

    @property
    @pulumi.getter
    def schedules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WlanScheduleArgs']]]]:
        """
        Start and stop schedules for the WLAN
        """
        return pulumi.get(self, "schedules")

    @schedules.setter
    def schedules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WlanScheduleArgs']]]]):
        pulumi.set(self, "schedules", value)

    @property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the site to associate the wlan with.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "site", value)

    @property
    @pulumi.getter
    def uapsd(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable Unscheduled Automatic Power Save Delivery Defaults to `false`.
        """
        return pulumi.get(self, "uapsd")

    @uapsd.setter
    def uapsd(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "uapsd", value)

    @property
    @pulumi.getter(name="wlanBand")
    def wlan_band(self) -> Optional[pulumi.Input[str]]:
        """
        Radio band your WiFi network will use.
        """
        return pulumi.get(self, "wlan_band")

    @wlan_band.setter
    def wlan_band(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "wlan_band", value)

    @property
    @pulumi.getter(name="wpa3Support")
    def wpa3_support(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable WPA 3 support (security must be `wpapsk` and PMF must be turned on).
        """
        return pulumi.get(self, "wpa3_support")

    @wpa3_support.setter
    def wpa3_support(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "wpa3_support", value)

    @property
    @pulumi.getter(name="wpa3Transition")
    def wpa3_transition(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable WPA 3 and WPA 2 support (security must be `wpapsk` and `wpa3_support` must be true).
        """
        return pulumi.get(self, "wpa3_transition")

    @wpa3_transition.setter
    def wpa3_transition(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "wpa3_transition", value)


@pulumi.input_type
class _WlanState:
    def __init__(__self__, *,
                 ap_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 hide_ssid: Optional[pulumi.Input[bool]] = None,
                 is_guest: Optional[pulumi.Input[bool]] = None,
                 l2_isolation: Optional[pulumi.Input[bool]] = None,
                 mac_filter_enabled: Optional[pulumi.Input[bool]] = None,
                 mac_filter_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 mac_filter_policy: Optional[pulumi.Input[str]] = None,
                 minimum_data_rate2g_kbps: Optional[pulumi.Input[int]] = None,
                 minimum_data_rate5g_kbps: Optional[pulumi.Input[int]] = None,
                 multicast_enhance: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_id: Optional[pulumi.Input[str]] = None,
                 no2ghz_oui: Optional[pulumi.Input[bool]] = None,
                 passphrase: Optional[pulumi.Input[str]] = None,
                 pmf_mode: Optional[pulumi.Input[str]] = None,
                 radius_profile_id: Optional[pulumi.Input[str]] = None,
                 schedules: Optional[pulumi.Input[Sequence[pulumi.Input['WlanScheduleArgs']]]] = None,
                 security: Optional[pulumi.Input[str]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 uapsd: Optional[pulumi.Input[bool]] = None,
                 user_group_id: Optional[pulumi.Input[str]] = None,
                 wlan_band: Optional[pulumi.Input[str]] = None,
                 wpa3_support: Optional[pulumi.Input[bool]] = None,
                 wpa3_transition: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering Wlan resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] ap_group_ids: IDs of the AP groups to use for this network.
        :param pulumi.Input[bool] hide_ssid: Indicates whether or not to hide the SSID from broadcast.
        :param pulumi.Input[bool] is_guest: Indicates that this is a guest WLAN and should use guest behaviors.
        :param pulumi.Input[bool] l2_isolation: Isolates stations on layer 2 (ethernet) level Defaults to `false`.
        :param pulumi.Input[bool] mac_filter_enabled: Indicates whether or not the MAC filter is turned of for the network.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] mac_filter_lists: List of MAC addresses to filter (only valid if `mac_filter_enabled` is `true`).
        :param pulumi.Input[str] mac_filter_policy: MAC address filter policy (only valid if `mac_filter_enabled` is `true`). Defaults to `deny`.
        :param pulumi.Input[int] minimum_data_rate2g_kbps: Set minimum data rate control for 2G devices, in Kbps. Use `0` to disable minimum data rates. Valid values are: `1000`, `2000`, `5500`, `6000`, `9000`, `11000`, `12000`, `18000`, `24000`, `36000`, `48000`,  and `54000`.
        :param pulumi.Input[int] minimum_data_rate5g_kbps: Set minimum data rate control for 5G devices, in Kbps. Use `0` to disable minimum data rates. Valid values are: `6000`, `9000`, `12000`, `18000`, `24000`, `36000`, `48000`,  and `54000`.
        :param pulumi.Input[bool] multicast_enhance: Indicates whether or not Multicast Enhance is turned of for the network.
        :param pulumi.Input[str] name: The SSID of the network.
        :param pulumi.Input[str] network_id: ID of the network for this SSID
        :param pulumi.Input[bool] no2ghz_oui: Connect high performance clients to 5 GHz only Defaults to `true`.
        :param pulumi.Input[str] passphrase: The passphrase for the network, this is only required if `security` is not set to `open`.
        :param pulumi.Input[str] pmf_mode: Enable Protected Management Frames. This cannot be disabled if using WPA 3. Valid values are `required`, `optional` and `disabled`. Defaults to `disabled`.
        :param pulumi.Input[str] radius_profile_id: ID of the RADIUS profile to use when security `wpaeap`. You can query this via the `get_radius_profile` data source.
        :param pulumi.Input[Sequence[pulumi.Input['WlanScheduleArgs']]] schedules: Start and stop schedules for the WLAN
        :param pulumi.Input[str] security: The type of WiFi security for this network. Valid values are: `wpapsk`, `wpaeap`, and `open`.
        :param pulumi.Input[str] site: The name of the site to associate the wlan with.
        :param pulumi.Input[bool] uapsd: Enable Unscheduled Automatic Power Save Delivery Defaults to `false`.
        :param pulumi.Input[str] user_group_id: ID of the user group to use for this network.
        :param pulumi.Input[str] wlan_band: Radio band your WiFi network will use.
        :param pulumi.Input[bool] wpa3_support: Enable WPA 3 support (security must be `wpapsk` and PMF must be turned on).
        :param pulumi.Input[bool] wpa3_transition: Enable WPA 3 and WPA 2 support (security must be `wpapsk` and `wpa3_support` must be true).
        """
        if ap_group_ids is not None:
            pulumi.set(__self__, "ap_group_ids", ap_group_ids)
        if hide_ssid is not None:
            pulumi.set(__self__, "hide_ssid", hide_ssid)
        if is_guest is not None:
            pulumi.set(__self__, "is_guest", is_guest)
        if l2_isolation is not None:
            pulumi.set(__self__, "l2_isolation", l2_isolation)
        if mac_filter_enabled is not None:
            pulumi.set(__self__, "mac_filter_enabled", mac_filter_enabled)
        if mac_filter_lists is not None:
            pulumi.set(__self__, "mac_filter_lists", mac_filter_lists)
        if mac_filter_policy is not None:
            pulumi.set(__self__, "mac_filter_policy", mac_filter_policy)
        if minimum_data_rate2g_kbps is not None:
            pulumi.set(__self__, "minimum_data_rate2g_kbps", minimum_data_rate2g_kbps)
        if minimum_data_rate5g_kbps is not None:
            pulumi.set(__self__, "minimum_data_rate5g_kbps", minimum_data_rate5g_kbps)
        if multicast_enhance is not None:
            pulumi.set(__self__, "multicast_enhance", multicast_enhance)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network_id is not None:
            pulumi.set(__self__, "network_id", network_id)
        if no2ghz_oui is not None:
            pulumi.set(__self__, "no2ghz_oui", no2ghz_oui)
        if passphrase is not None:
            pulumi.set(__self__, "passphrase", passphrase)
        if pmf_mode is not None:
            pulumi.set(__self__, "pmf_mode", pmf_mode)
        if radius_profile_id is not None:
            pulumi.set(__self__, "radius_profile_id", radius_profile_id)
        if schedules is not None:
            pulumi.set(__self__, "schedules", schedules)
        if security is not None:
            pulumi.set(__self__, "security", security)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if uapsd is not None:
            pulumi.set(__self__, "uapsd", uapsd)
        if user_group_id is not None:
            pulumi.set(__self__, "user_group_id", user_group_id)
        if wlan_band is not None:
            pulumi.set(__self__, "wlan_band", wlan_band)
        if wpa3_support is not None:
            pulumi.set(__self__, "wpa3_support", wpa3_support)
        if wpa3_transition is not None:
            pulumi.set(__self__, "wpa3_transition", wpa3_transition)

    @property
    @pulumi.getter(name="apGroupIds")
    def ap_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        IDs of the AP groups to use for this network.
        """
        return pulumi.get(self, "ap_group_ids")

    @ap_group_ids.setter
    def ap_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "ap_group_ids", value)

    @property
    @pulumi.getter(name="hideSsid")
    def hide_ssid(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether or not to hide the SSID from broadcast.
        """
        return pulumi.get(self, "hide_ssid")

    @hide_ssid.setter
    def hide_ssid(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "hide_ssid", value)

    @property
    @pulumi.getter(name="isGuest")
    def is_guest(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates that this is a guest WLAN and should use guest behaviors.
        """
        return pulumi.get(self, "is_guest")

    @is_guest.setter
    def is_guest(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_guest", value)

    @property
    @pulumi.getter(name="l2Isolation")
    def l2_isolation(self) -> Optional[pulumi.Input[bool]]:
        """
        Isolates stations on layer 2 (ethernet) level Defaults to `false`.
        """
        return pulumi.get(self, "l2_isolation")

    @l2_isolation.setter
    def l2_isolation(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "l2_isolation", value)

    @property
    @pulumi.getter(name="macFilterEnabled")
    def mac_filter_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether or not the MAC filter is turned of for the network.
        """
        return pulumi.get(self, "mac_filter_enabled")

    @mac_filter_enabled.setter
    def mac_filter_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "mac_filter_enabled", value)

    @property
    @pulumi.getter(name="macFilterLists")
    def mac_filter_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of MAC addresses to filter (only valid if `mac_filter_enabled` is `true`).
        """
        return pulumi.get(self, "mac_filter_lists")

    @mac_filter_lists.setter
    def mac_filter_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "mac_filter_lists", value)

    @property
    @pulumi.getter(name="macFilterPolicy")
    def mac_filter_policy(self) -> Optional[pulumi.Input[str]]:
        """
        MAC address filter policy (only valid if `mac_filter_enabled` is `true`). Defaults to `deny`.
        """
        return pulumi.get(self, "mac_filter_policy")

    @mac_filter_policy.setter
    def mac_filter_policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mac_filter_policy", value)

    @property
    @pulumi.getter(name="minimumDataRate2gKbps")
    def minimum_data_rate2g_kbps(self) -> Optional[pulumi.Input[int]]:
        """
        Set minimum data rate control for 2G devices, in Kbps. Use `0` to disable minimum data rates. Valid values are: `1000`, `2000`, `5500`, `6000`, `9000`, `11000`, `12000`, `18000`, `24000`, `36000`, `48000`,  and `54000`.
        """
        return pulumi.get(self, "minimum_data_rate2g_kbps")

    @minimum_data_rate2g_kbps.setter
    def minimum_data_rate2g_kbps(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "minimum_data_rate2g_kbps", value)

    @property
    @pulumi.getter(name="minimumDataRate5gKbps")
    def minimum_data_rate5g_kbps(self) -> Optional[pulumi.Input[int]]:
        """
        Set minimum data rate control for 5G devices, in Kbps. Use `0` to disable minimum data rates. Valid values are: `6000`, `9000`, `12000`, `18000`, `24000`, `36000`, `48000`,  and `54000`.
        """
        return pulumi.get(self, "minimum_data_rate5g_kbps")

    @minimum_data_rate5g_kbps.setter
    def minimum_data_rate5g_kbps(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "minimum_data_rate5g_kbps", value)

    @property
    @pulumi.getter(name="multicastEnhance")
    def multicast_enhance(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether or not Multicast Enhance is turned of for the network.
        """
        return pulumi.get(self, "multicast_enhance")

    @multicast_enhance.setter
    def multicast_enhance(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "multicast_enhance", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The SSID of the network.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the network for this SSID
        """
        return pulumi.get(self, "network_id")

    @network_id.setter
    def network_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "network_id", value)

    @property
    @pulumi.getter(name="no2ghzOui")
    def no2ghz_oui(self) -> Optional[pulumi.Input[bool]]:
        """
        Connect high performance clients to 5 GHz only Defaults to `true`.
        """
        return pulumi.get(self, "no2ghz_oui")

    @no2ghz_oui.setter
    def no2ghz_oui(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "no2ghz_oui", value)

    @property
    @pulumi.getter
    def passphrase(self) -> Optional[pulumi.Input[str]]:
        """
        The passphrase for the network, this is only required if `security` is not set to `open`.
        """
        return pulumi.get(self, "passphrase")

    @passphrase.setter
    def passphrase(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "passphrase", value)

    @property
    @pulumi.getter(name="pmfMode")
    def pmf_mode(self) -> Optional[pulumi.Input[str]]:
        """
        Enable Protected Management Frames. This cannot be disabled if using WPA 3. Valid values are `required`, `optional` and `disabled`. Defaults to `disabled`.
        """
        return pulumi.get(self, "pmf_mode")

    @pmf_mode.setter
    def pmf_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pmf_mode", value)

    @property
    @pulumi.getter(name="radiusProfileId")
    def radius_profile_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the RADIUS profile to use when security `wpaeap`. You can query this via the `get_radius_profile` data source.
        """
        return pulumi.get(self, "radius_profile_id")

    @radius_profile_id.setter
    def radius_profile_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "radius_profile_id", value)

    @property
    @pulumi.getter
    def schedules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WlanScheduleArgs']]]]:
        """
        Start and stop schedules for the WLAN
        """
        return pulumi.get(self, "schedules")

    @schedules.setter
    def schedules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WlanScheduleArgs']]]]):
        pulumi.set(self, "schedules", value)

    @property
    @pulumi.getter
    def security(self) -> Optional[pulumi.Input[str]]:
        """
        The type of WiFi security for this network. Valid values are: `wpapsk`, `wpaeap`, and `open`.
        """
        return pulumi.get(self, "security")

    @security.setter
    def security(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "security", value)

    @property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the site to associate the wlan with.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "site", value)

    @property
    @pulumi.getter
    def uapsd(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable Unscheduled Automatic Power Save Delivery Defaults to `false`.
        """
        return pulumi.get(self, "uapsd")

    @uapsd.setter
    def uapsd(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "uapsd", value)

    @property
    @pulumi.getter(name="userGroupId")
    def user_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the user group to use for this network.
        """
        return pulumi.get(self, "user_group_id")

    @user_group_id.setter
    def user_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_group_id", value)

    @property
    @pulumi.getter(name="wlanBand")
    def wlan_band(self) -> Optional[pulumi.Input[str]]:
        """
        Radio band your WiFi network will use.
        """
        return pulumi.get(self, "wlan_band")

    @wlan_band.setter
    def wlan_band(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "wlan_band", value)

    @property
    @pulumi.getter(name="wpa3Support")
    def wpa3_support(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable WPA 3 support (security must be `wpapsk` and PMF must be turned on).
        """
        return pulumi.get(self, "wpa3_support")

    @wpa3_support.setter
    def wpa3_support(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "wpa3_support", value)

    @property
    @pulumi.getter(name="wpa3Transition")
    def wpa3_transition(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable WPA 3 and WPA 2 support (security must be `wpapsk` and `wpa3_support` must be true).
        """
        return pulumi.get(self, "wpa3_transition")

    @wpa3_transition.setter
    def wpa3_transition(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "wpa3_transition", value)


class Wlan(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ap_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 hide_ssid: Optional[pulumi.Input[bool]] = None,
                 is_guest: Optional[pulumi.Input[bool]] = None,
                 l2_isolation: Optional[pulumi.Input[bool]] = None,
                 mac_filter_enabled: Optional[pulumi.Input[bool]] = None,
                 mac_filter_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 mac_filter_policy: Optional[pulumi.Input[str]] = None,
                 minimum_data_rate2g_kbps: Optional[pulumi.Input[int]] = None,
                 minimum_data_rate5g_kbps: Optional[pulumi.Input[int]] = None,
                 multicast_enhance: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_id: Optional[pulumi.Input[str]] = None,
                 no2ghz_oui: Optional[pulumi.Input[bool]] = None,
                 passphrase: Optional[pulumi.Input[str]] = None,
                 pmf_mode: Optional[pulumi.Input[str]] = None,
                 radius_profile_id: Optional[pulumi.Input[str]] = None,
                 schedules: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['WlanScheduleArgs']]]]] = None,
                 security: Optional[pulumi.Input[str]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 uapsd: Optional[pulumi.Input[bool]] = None,
                 user_group_id: Optional[pulumi.Input[str]] = None,
                 wlan_band: Optional[pulumi.Input[str]] = None,
                 wpa3_support: Optional[pulumi.Input[bool]] = None,
                 wpa3_transition: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        `Wlan` manages a WiFi network / SSID.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_unifi as unifi
        import pulumiverse_unifi as unifi

        config = pulumi.Config()
        vlan_id = config.get_float("vlanId")
        if vlan_id is None:
            vlan_id = 10
        default_ap_group = unifi.get_ap_group()
        default_group = unifi.iam.get_group()
        vlan = unifi.Network("vlan",
            purpose="corporate",
            subnet="10.0.0.1/24",
            vlan_id=vlan_id,
            dhcp_start="10.0.0.6",
            dhcp_stop="10.0.0.254",
            dhcp_enabled=True)
        wifi = unifi.Wlan("wifi",
            passphrase="12345678",
            security="wpapsk",
            wpa3_support=True,
            wpa3_transition=True,
            pmf_mode="optional",
            network_id=vlan.id,
            ap_group_ids=[default_ap_group.id],
            user_group_id=default_group.id)
        ```

        ## Import

        import from provider configured site

        ```sh
         $ pulumi import unifi:index/wlan:Wlan mywlan 5dc28e5e9106d105bdc87217
        ```

         import from another site

        ```sh
         $ pulumi import unifi:index/wlan:Wlan mywlan bfa2l6i7:5dc28e5e9106d105bdc87217
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] ap_group_ids: IDs of the AP groups to use for this network.
        :param pulumi.Input[bool] hide_ssid: Indicates whether or not to hide the SSID from broadcast.
        :param pulumi.Input[bool] is_guest: Indicates that this is a guest WLAN and should use guest behaviors.
        :param pulumi.Input[bool] l2_isolation: Isolates stations on layer 2 (ethernet) level Defaults to `false`.
        :param pulumi.Input[bool] mac_filter_enabled: Indicates whether or not the MAC filter is turned of for the network.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] mac_filter_lists: List of MAC addresses to filter (only valid if `mac_filter_enabled` is `true`).
        :param pulumi.Input[str] mac_filter_policy: MAC address filter policy (only valid if `mac_filter_enabled` is `true`). Defaults to `deny`.
        :param pulumi.Input[int] minimum_data_rate2g_kbps: Set minimum data rate control for 2G devices, in Kbps. Use `0` to disable minimum data rates. Valid values are: `1000`, `2000`, `5500`, `6000`, `9000`, `11000`, `12000`, `18000`, `24000`, `36000`, `48000`,  and `54000`.
        :param pulumi.Input[int] minimum_data_rate5g_kbps: Set minimum data rate control for 5G devices, in Kbps. Use `0` to disable minimum data rates. Valid values are: `6000`, `9000`, `12000`, `18000`, `24000`, `36000`, `48000`,  and `54000`.
        :param pulumi.Input[bool] multicast_enhance: Indicates whether or not Multicast Enhance is turned of for the network.
        :param pulumi.Input[str] name: The SSID of the network.
        :param pulumi.Input[str] network_id: ID of the network for this SSID
        :param pulumi.Input[bool] no2ghz_oui: Connect high performance clients to 5 GHz only Defaults to `true`.
        :param pulumi.Input[str] passphrase: The passphrase for the network, this is only required if `security` is not set to `open`.
        :param pulumi.Input[str] pmf_mode: Enable Protected Management Frames. This cannot be disabled if using WPA 3. Valid values are `required`, `optional` and `disabled`. Defaults to `disabled`.
        :param pulumi.Input[str] radius_profile_id: ID of the RADIUS profile to use when security `wpaeap`. You can query this via the `get_radius_profile` data source.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['WlanScheduleArgs']]]] schedules: Start and stop schedules for the WLAN
        :param pulumi.Input[str] security: The type of WiFi security for this network. Valid values are: `wpapsk`, `wpaeap`, and `open`.
        :param pulumi.Input[str] site: The name of the site to associate the wlan with.
        :param pulumi.Input[bool] uapsd: Enable Unscheduled Automatic Power Save Delivery Defaults to `false`.
        :param pulumi.Input[str] user_group_id: ID of the user group to use for this network.
        :param pulumi.Input[str] wlan_band: Radio band your WiFi network will use.
        :param pulumi.Input[bool] wpa3_support: Enable WPA 3 support (security must be `wpapsk` and PMF must be turned on).
        :param pulumi.Input[bool] wpa3_transition: Enable WPA 3 and WPA 2 support (security must be `wpapsk` and `wpa3_support` must be true).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WlanArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `Wlan` manages a WiFi network / SSID.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_unifi as unifi
        import pulumiverse_unifi as unifi

        config = pulumi.Config()
        vlan_id = config.get_float("vlanId")
        if vlan_id is None:
            vlan_id = 10
        default_ap_group = unifi.get_ap_group()
        default_group = unifi.iam.get_group()
        vlan = unifi.Network("vlan",
            purpose="corporate",
            subnet="10.0.0.1/24",
            vlan_id=vlan_id,
            dhcp_start="10.0.0.6",
            dhcp_stop="10.0.0.254",
            dhcp_enabled=True)
        wifi = unifi.Wlan("wifi",
            passphrase="12345678",
            security="wpapsk",
            wpa3_support=True,
            wpa3_transition=True,
            pmf_mode="optional",
            network_id=vlan.id,
            ap_group_ids=[default_ap_group.id],
            user_group_id=default_group.id)
        ```

        ## Import

        import from provider configured site

        ```sh
         $ pulumi import unifi:index/wlan:Wlan mywlan 5dc28e5e9106d105bdc87217
        ```

         import from another site

        ```sh
         $ pulumi import unifi:index/wlan:Wlan mywlan bfa2l6i7:5dc28e5e9106d105bdc87217
        ```

        :param str resource_name: The name of the resource.
        :param WlanArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WlanArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ap_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 hide_ssid: Optional[pulumi.Input[bool]] = None,
                 is_guest: Optional[pulumi.Input[bool]] = None,
                 l2_isolation: Optional[pulumi.Input[bool]] = None,
                 mac_filter_enabled: Optional[pulumi.Input[bool]] = None,
                 mac_filter_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 mac_filter_policy: Optional[pulumi.Input[str]] = None,
                 minimum_data_rate2g_kbps: Optional[pulumi.Input[int]] = None,
                 minimum_data_rate5g_kbps: Optional[pulumi.Input[int]] = None,
                 multicast_enhance: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_id: Optional[pulumi.Input[str]] = None,
                 no2ghz_oui: Optional[pulumi.Input[bool]] = None,
                 passphrase: Optional[pulumi.Input[str]] = None,
                 pmf_mode: Optional[pulumi.Input[str]] = None,
                 radius_profile_id: Optional[pulumi.Input[str]] = None,
                 schedules: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['WlanScheduleArgs']]]]] = None,
                 security: Optional[pulumi.Input[str]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 uapsd: Optional[pulumi.Input[bool]] = None,
                 user_group_id: Optional[pulumi.Input[str]] = None,
                 wlan_band: Optional[pulumi.Input[str]] = None,
                 wpa3_support: Optional[pulumi.Input[bool]] = None,
                 wpa3_transition: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WlanArgs.__new__(WlanArgs)

            __props__.__dict__["ap_group_ids"] = ap_group_ids
            __props__.__dict__["hide_ssid"] = hide_ssid
            __props__.__dict__["is_guest"] = is_guest
            __props__.__dict__["l2_isolation"] = l2_isolation
            __props__.__dict__["mac_filter_enabled"] = mac_filter_enabled
            __props__.__dict__["mac_filter_lists"] = mac_filter_lists
            __props__.__dict__["mac_filter_policy"] = mac_filter_policy
            __props__.__dict__["minimum_data_rate2g_kbps"] = minimum_data_rate2g_kbps
            __props__.__dict__["minimum_data_rate5g_kbps"] = minimum_data_rate5g_kbps
            __props__.__dict__["multicast_enhance"] = multicast_enhance
            __props__.__dict__["name"] = name
            __props__.__dict__["network_id"] = network_id
            __props__.__dict__["no2ghz_oui"] = no2ghz_oui
            __props__.__dict__["passphrase"] = None if passphrase is None else pulumi.Output.secret(passphrase)
            __props__.__dict__["pmf_mode"] = pmf_mode
            __props__.__dict__["radius_profile_id"] = radius_profile_id
            __props__.__dict__["schedules"] = schedules
            if security is None and not opts.urn:
                raise TypeError("Missing required property 'security'")
            __props__.__dict__["security"] = security
            __props__.__dict__["site"] = site
            __props__.__dict__["uapsd"] = uapsd
            if user_group_id is None and not opts.urn:
                raise TypeError("Missing required property 'user_group_id'")
            __props__.__dict__["user_group_id"] = user_group_id
            __props__.__dict__["wlan_band"] = wlan_band
            __props__.__dict__["wpa3_support"] = wpa3_support
            __props__.__dict__["wpa3_transition"] = wpa3_transition
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["passphrase"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Wlan, __self__).__init__(
            'unifi:index/wlan:Wlan',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            ap_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            hide_ssid: Optional[pulumi.Input[bool]] = None,
            is_guest: Optional[pulumi.Input[bool]] = None,
            l2_isolation: Optional[pulumi.Input[bool]] = None,
            mac_filter_enabled: Optional[pulumi.Input[bool]] = None,
            mac_filter_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            mac_filter_policy: Optional[pulumi.Input[str]] = None,
            minimum_data_rate2g_kbps: Optional[pulumi.Input[int]] = None,
            minimum_data_rate5g_kbps: Optional[pulumi.Input[int]] = None,
            multicast_enhance: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            network_id: Optional[pulumi.Input[str]] = None,
            no2ghz_oui: Optional[pulumi.Input[bool]] = None,
            passphrase: Optional[pulumi.Input[str]] = None,
            pmf_mode: Optional[pulumi.Input[str]] = None,
            radius_profile_id: Optional[pulumi.Input[str]] = None,
            schedules: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['WlanScheduleArgs']]]]] = None,
            security: Optional[pulumi.Input[str]] = None,
            site: Optional[pulumi.Input[str]] = None,
            uapsd: Optional[pulumi.Input[bool]] = None,
            user_group_id: Optional[pulumi.Input[str]] = None,
            wlan_band: Optional[pulumi.Input[str]] = None,
            wpa3_support: Optional[pulumi.Input[bool]] = None,
            wpa3_transition: Optional[pulumi.Input[bool]] = None) -> 'Wlan':
        """
        Get an existing Wlan resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] ap_group_ids: IDs of the AP groups to use for this network.
        :param pulumi.Input[bool] hide_ssid: Indicates whether or not to hide the SSID from broadcast.
        :param pulumi.Input[bool] is_guest: Indicates that this is a guest WLAN and should use guest behaviors.
        :param pulumi.Input[bool] l2_isolation: Isolates stations on layer 2 (ethernet) level Defaults to `false`.
        :param pulumi.Input[bool] mac_filter_enabled: Indicates whether or not the MAC filter is turned of for the network.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] mac_filter_lists: List of MAC addresses to filter (only valid if `mac_filter_enabled` is `true`).
        :param pulumi.Input[str] mac_filter_policy: MAC address filter policy (only valid if `mac_filter_enabled` is `true`). Defaults to `deny`.
        :param pulumi.Input[int] minimum_data_rate2g_kbps: Set minimum data rate control for 2G devices, in Kbps. Use `0` to disable minimum data rates. Valid values are: `1000`, `2000`, `5500`, `6000`, `9000`, `11000`, `12000`, `18000`, `24000`, `36000`, `48000`,  and `54000`.
        :param pulumi.Input[int] minimum_data_rate5g_kbps: Set minimum data rate control for 5G devices, in Kbps. Use `0` to disable minimum data rates. Valid values are: `6000`, `9000`, `12000`, `18000`, `24000`, `36000`, `48000`,  and `54000`.
        :param pulumi.Input[bool] multicast_enhance: Indicates whether or not Multicast Enhance is turned of for the network.
        :param pulumi.Input[str] name: The SSID of the network.
        :param pulumi.Input[str] network_id: ID of the network for this SSID
        :param pulumi.Input[bool] no2ghz_oui: Connect high performance clients to 5 GHz only Defaults to `true`.
        :param pulumi.Input[str] passphrase: The passphrase for the network, this is only required if `security` is not set to `open`.
        :param pulumi.Input[str] pmf_mode: Enable Protected Management Frames. This cannot be disabled if using WPA 3. Valid values are `required`, `optional` and `disabled`. Defaults to `disabled`.
        :param pulumi.Input[str] radius_profile_id: ID of the RADIUS profile to use when security `wpaeap`. You can query this via the `get_radius_profile` data source.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['WlanScheduleArgs']]]] schedules: Start and stop schedules for the WLAN
        :param pulumi.Input[str] security: The type of WiFi security for this network. Valid values are: `wpapsk`, `wpaeap`, and `open`.
        :param pulumi.Input[str] site: The name of the site to associate the wlan with.
        :param pulumi.Input[bool] uapsd: Enable Unscheduled Automatic Power Save Delivery Defaults to `false`.
        :param pulumi.Input[str] user_group_id: ID of the user group to use for this network.
        :param pulumi.Input[str] wlan_band: Radio band your WiFi network will use.
        :param pulumi.Input[bool] wpa3_support: Enable WPA 3 support (security must be `wpapsk` and PMF must be turned on).
        :param pulumi.Input[bool] wpa3_transition: Enable WPA 3 and WPA 2 support (security must be `wpapsk` and `wpa3_support` must be true).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WlanState.__new__(_WlanState)

        __props__.__dict__["ap_group_ids"] = ap_group_ids
        __props__.__dict__["hide_ssid"] = hide_ssid
        __props__.__dict__["is_guest"] = is_guest
        __props__.__dict__["l2_isolation"] = l2_isolation
        __props__.__dict__["mac_filter_enabled"] = mac_filter_enabled
        __props__.__dict__["mac_filter_lists"] = mac_filter_lists
        __props__.__dict__["mac_filter_policy"] = mac_filter_policy
        __props__.__dict__["minimum_data_rate2g_kbps"] = minimum_data_rate2g_kbps
        __props__.__dict__["minimum_data_rate5g_kbps"] = minimum_data_rate5g_kbps
        __props__.__dict__["multicast_enhance"] = multicast_enhance
        __props__.__dict__["name"] = name
        __props__.__dict__["network_id"] = network_id
        __props__.__dict__["no2ghz_oui"] = no2ghz_oui
        __props__.__dict__["passphrase"] = passphrase
        __props__.__dict__["pmf_mode"] = pmf_mode
        __props__.__dict__["radius_profile_id"] = radius_profile_id
        __props__.__dict__["schedules"] = schedules
        __props__.__dict__["security"] = security
        __props__.__dict__["site"] = site
        __props__.__dict__["uapsd"] = uapsd
        __props__.__dict__["user_group_id"] = user_group_id
        __props__.__dict__["wlan_band"] = wlan_band
        __props__.__dict__["wpa3_support"] = wpa3_support
        __props__.__dict__["wpa3_transition"] = wpa3_transition
        return Wlan(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="apGroupIds")
    def ap_group_ids(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        IDs of the AP groups to use for this network.
        """
        return pulumi.get(self, "ap_group_ids")

    @property
    @pulumi.getter(name="hideSsid")
    def hide_ssid(self) -> pulumi.Output[Optional[bool]]:
        """
        Indicates whether or not to hide the SSID from broadcast.
        """
        return pulumi.get(self, "hide_ssid")

    @property
    @pulumi.getter(name="isGuest")
    def is_guest(self) -> pulumi.Output[Optional[bool]]:
        """
        Indicates that this is a guest WLAN and should use guest behaviors.
        """
        return pulumi.get(self, "is_guest")

    @property
    @pulumi.getter(name="l2Isolation")
    def l2_isolation(self) -> pulumi.Output[Optional[bool]]:
        """
        Isolates stations on layer 2 (ethernet) level Defaults to `false`.
        """
        return pulumi.get(self, "l2_isolation")

    @property
    @pulumi.getter(name="macFilterEnabled")
    def mac_filter_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Indicates whether or not the MAC filter is turned of for the network.
        """
        return pulumi.get(self, "mac_filter_enabled")

    @property
    @pulumi.getter(name="macFilterLists")
    def mac_filter_lists(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        List of MAC addresses to filter (only valid if `mac_filter_enabled` is `true`).
        """
        return pulumi.get(self, "mac_filter_lists")

    @property
    @pulumi.getter(name="macFilterPolicy")
    def mac_filter_policy(self) -> pulumi.Output[Optional[str]]:
        """
        MAC address filter policy (only valid if `mac_filter_enabled` is `true`). Defaults to `deny`.
        """
        return pulumi.get(self, "mac_filter_policy")

    @property
    @pulumi.getter(name="minimumDataRate2gKbps")
    def minimum_data_rate2g_kbps(self) -> pulumi.Output[Optional[int]]:
        """
        Set minimum data rate control for 2G devices, in Kbps. Use `0` to disable minimum data rates. Valid values are: `1000`, `2000`, `5500`, `6000`, `9000`, `11000`, `12000`, `18000`, `24000`, `36000`, `48000`,  and `54000`.
        """
        return pulumi.get(self, "minimum_data_rate2g_kbps")

    @property
    @pulumi.getter(name="minimumDataRate5gKbps")
    def minimum_data_rate5g_kbps(self) -> pulumi.Output[Optional[int]]:
        """
        Set minimum data rate control for 5G devices, in Kbps. Use `0` to disable minimum data rates. Valid values are: `6000`, `9000`, `12000`, `18000`, `24000`, `36000`, `48000`,  and `54000`.
        """
        return pulumi.get(self, "minimum_data_rate5g_kbps")

    @property
    @pulumi.getter(name="multicastEnhance")
    def multicast_enhance(self) -> pulumi.Output[Optional[bool]]:
        """
        Indicates whether or not Multicast Enhance is turned of for the network.
        """
        return pulumi.get(self, "multicast_enhance")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The SSID of the network.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> pulumi.Output[Optional[str]]:
        """
        ID of the network for this SSID
        """
        return pulumi.get(self, "network_id")

    @property
    @pulumi.getter(name="no2ghzOui")
    def no2ghz_oui(self) -> pulumi.Output[Optional[bool]]:
        """
        Connect high performance clients to 5 GHz only Defaults to `true`.
        """
        return pulumi.get(self, "no2ghz_oui")

    @property
    @pulumi.getter
    def passphrase(self) -> pulumi.Output[Optional[str]]:
        """
        The passphrase for the network, this is only required if `security` is not set to `open`.
        """
        return pulumi.get(self, "passphrase")

    @property
    @pulumi.getter(name="pmfMode")
    def pmf_mode(self) -> pulumi.Output[Optional[str]]:
        """
        Enable Protected Management Frames. This cannot be disabled if using WPA 3. Valid values are `required`, `optional` and `disabled`. Defaults to `disabled`.
        """
        return pulumi.get(self, "pmf_mode")

    @property
    @pulumi.getter(name="radiusProfileId")
    def radius_profile_id(self) -> pulumi.Output[Optional[str]]:
        """
        ID of the RADIUS profile to use when security `wpaeap`. You can query this via the `get_radius_profile` data source.
        """
        return pulumi.get(self, "radius_profile_id")

    @property
    @pulumi.getter
    def schedules(self) -> pulumi.Output[Optional[Sequence['outputs.WlanSchedule']]]:
        """
        Start and stop schedules for the WLAN
        """
        return pulumi.get(self, "schedules")

    @property
    @pulumi.getter
    def security(self) -> pulumi.Output[str]:
        """
        The type of WiFi security for this network. Valid values are: `wpapsk`, `wpaeap`, and `open`.
        """
        return pulumi.get(self, "security")

    @property
    @pulumi.getter
    def site(self) -> pulumi.Output[str]:
        """
        The name of the site to associate the wlan with.
        """
        return pulumi.get(self, "site")

    @property
    @pulumi.getter
    def uapsd(self) -> pulumi.Output[Optional[bool]]:
        """
        Enable Unscheduled Automatic Power Save Delivery Defaults to `false`.
        """
        return pulumi.get(self, "uapsd")

    @property
    @pulumi.getter(name="userGroupId")
    def user_group_id(self) -> pulumi.Output[str]:
        """
        ID of the user group to use for this network.
        """
        return pulumi.get(self, "user_group_id")

    @property
    @pulumi.getter(name="wlanBand")
    def wlan_band(self) -> pulumi.Output[Optional[str]]:
        """
        Radio band your WiFi network will use.
        """
        return pulumi.get(self, "wlan_band")

    @property
    @pulumi.getter(name="wpa3Support")
    def wpa3_support(self) -> pulumi.Output[Optional[bool]]:
        """
        Enable WPA 3 support (security must be `wpapsk` and PMF must be turned on).
        """
        return pulumi.get(self, "wpa3_support")

    @property
    @pulumi.getter(name="wpa3Transition")
    def wpa3_transition(self) -> pulumi.Output[Optional[bool]]:
        """
        Enable WPA 3 and WPA 2 support (security must be `wpapsk` and `wpa3_support` must be true).
        """
        return pulumi.get(self, "wpa3_transition")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['USGArgs', 'USG']

@pulumi.input_type
class USGArgs:
    def __init__(__self__, *,
                 dhcp_relay_servers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 firewall_guest_default_log: Optional[pulumi.Input[bool]] = None,
                 firewall_lan_default_log: Optional[pulumi.Input[bool]] = None,
                 firewall_wan_default_log: Optional[pulumi.Input[bool]] = None,
                 multicast_dns_enabled: Optional[pulumi.Input[bool]] = None,
                 site: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a USG resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dhcp_relay_servers: The DHCP relay servers.
        :param pulumi.Input[bool] firewall_guest_default_log: Whether the guest firewall log is enabled.
        :param pulumi.Input[bool] firewall_lan_default_log: Whether the LAN firewall log is enabled.
        :param pulumi.Input[bool] firewall_wan_default_log: Whether the WAN firewall log is enabled.
        :param pulumi.Input[bool] multicast_dns_enabled: Whether multicast DNS is enabled.
        :param pulumi.Input[str] site: The name of the site to associate the settings with.
        """
        if dhcp_relay_servers is not None:
            pulumi.set(__self__, "dhcp_relay_servers", dhcp_relay_servers)
        if firewall_guest_default_log is not None:
            pulumi.set(__self__, "firewall_guest_default_log", firewall_guest_default_log)
        if firewall_lan_default_log is not None:
            pulumi.set(__self__, "firewall_lan_default_log", firewall_lan_default_log)
        if firewall_wan_default_log is not None:
            pulumi.set(__self__, "firewall_wan_default_log", firewall_wan_default_log)
        if multicast_dns_enabled is not None:
            pulumi.set(__self__, "multicast_dns_enabled", multicast_dns_enabled)
        if site is not None:
            pulumi.set(__self__, "site", site)

    @property
    @pulumi.getter(name="dhcpRelayServers")
    def dhcp_relay_servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The DHCP relay servers.
        """
        return pulumi.get(self, "dhcp_relay_servers")

    @dhcp_relay_servers.setter
    def dhcp_relay_servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "dhcp_relay_servers", value)

    @property
    @pulumi.getter(name="firewallGuestDefaultLog")
    def firewall_guest_default_log(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the guest firewall log is enabled.
        """
        return pulumi.get(self, "firewall_guest_default_log")

    @firewall_guest_default_log.setter
    def firewall_guest_default_log(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "firewall_guest_default_log", value)

    @property
    @pulumi.getter(name="firewallLanDefaultLog")
    def firewall_lan_default_log(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the LAN firewall log is enabled.
        """
        return pulumi.get(self, "firewall_lan_default_log")

    @firewall_lan_default_log.setter
    def firewall_lan_default_log(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "firewall_lan_default_log", value)

    @property
    @pulumi.getter(name="firewallWanDefaultLog")
    def firewall_wan_default_log(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the WAN firewall log is enabled.
        """
        return pulumi.get(self, "firewall_wan_default_log")

    @firewall_wan_default_log.setter
    def firewall_wan_default_log(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "firewall_wan_default_log", value)

    @property
    @pulumi.getter(name="multicastDnsEnabled")
    def multicast_dns_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether multicast DNS is enabled.
        """
        return pulumi.get(self, "multicast_dns_enabled")

    @multicast_dns_enabled.setter
    def multicast_dns_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "multicast_dns_enabled", value)

    @property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the site to associate the settings with.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "site", value)


@pulumi.input_type
class _USGState:
    def __init__(__self__, *,
                 dhcp_relay_servers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 firewall_guest_default_log: Optional[pulumi.Input[bool]] = None,
                 firewall_lan_default_log: Optional[pulumi.Input[bool]] = None,
                 firewall_wan_default_log: Optional[pulumi.Input[bool]] = None,
                 multicast_dns_enabled: Optional[pulumi.Input[bool]] = None,
                 site: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering USG resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dhcp_relay_servers: The DHCP relay servers.
        :param pulumi.Input[bool] firewall_guest_default_log: Whether the guest firewall log is enabled.
        :param pulumi.Input[bool] firewall_lan_default_log: Whether the LAN firewall log is enabled.
        :param pulumi.Input[bool] firewall_wan_default_log: Whether the WAN firewall log is enabled.
        :param pulumi.Input[bool] multicast_dns_enabled: Whether multicast DNS is enabled.
        :param pulumi.Input[str] site: The name of the site to associate the settings with.
        """
        if dhcp_relay_servers is not None:
            pulumi.set(__self__, "dhcp_relay_servers", dhcp_relay_servers)
        if firewall_guest_default_log is not None:
            pulumi.set(__self__, "firewall_guest_default_log", firewall_guest_default_log)
        if firewall_lan_default_log is not None:
            pulumi.set(__self__, "firewall_lan_default_log", firewall_lan_default_log)
        if firewall_wan_default_log is not None:
            pulumi.set(__self__, "firewall_wan_default_log", firewall_wan_default_log)
        if multicast_dns_enabled is not None:
            pulumi.set(__self__, "multicast_dns_enabled", multicast_dns_enabled)
        if site is not None:
            pulumi.set(__self__, "site", site)

    @property
    @pulumi.getter(name="dhcpRelayServers")
    def dhcp_relay_servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The DHCP relay servers.
        """
        return pulumi.get(self, "dhcp_relay_servers")

    @dhcp_relay_servers.setter
    def dhcp_relay_servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "dhcp_relay_servers", value)

    @property
    @pulumi.getter(name="firewallGuestDefaultLog")
    def firewall_guest_default_log(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the guest firewall log is enabled.
        """
        return pulumi.get(self, "firewall_guest_default_log")

    @firewall_guest_default_log.setter
    def firewall_guest_default_log(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "firewall_guest_default_log", value)

    @property
    @pulumi.getter(name="firewallLanDefaultLog")
    def firewall_lan_default_log(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the LAN firewall log is enabled.
        """
        return pulumi.get(self, "firewall_lan_default_log")

    @firewall_lan_default_log.setter
    def firewall_lan_default_log(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "firewall_lan_default_log", value)

    @property
    @pulumi.getter(name="firewallWanDefaultLog")
    def firewall_wan_default_log(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the WAN firewall log is enabled.
        """
        return pulumi.get(self, "firewall_wan_default_log")

    @firewall_wan_default_log.setter
    def firewall_wan_default_log(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "firewall_wan_default_log", value)

    @property
    @pulumi.getter(name="multicastDnsEnabled")
    def multicast_dns_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether multicast DNS is enabled.
        """
        return pulumi.get(self, "multicast_dns_enabled")

    @multicast_dns_enabled.setter
    def multicast_dns_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "multicast_dns_enabled", value)

    @property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the site to associate the settings with.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "site", value)


class USG(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dhcp_relay_servers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 firewall_guest_default_log: Optional[pulumi.Input[bool]] = None,
                 firewall_lan_default_log: Optional[pulumi.Input[bool]] = None,
                 firewall_wan_default_log: Optional[pulumi.Input[bool]] = None,
                 multicast_dns_enabled: Optional[pulumi.Input[bool]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        `setting.USG` manages settings for a Unifi Security Gateway.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dhcp_relay_servers: The DHCP relay servers.
        :param pulumi.Input[bool] firewall_guest_default_log: Whether the guest firewall log is enabled.
        :param pulumi.Input[bool] firewall_lan_default_log: Whether the LAN firewall log is enabled.
        :param pulumi.Input[bool] firewall_wan_default_log: Whether the WAN firewall log is enabled.
        :param pulumi.Input[bool] multicast_dns_enabled: Whether multicast DNS is enabled.
        :param pulumi.Input[str] site: The name of the site to associate the settings with.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[USGArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `setting.USG` manages settings for a Unifi Security Gateway.

        :param str resource_name: The name of the resource.
        :param USGArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(USGArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dhcp_relay_servers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 firewall_guest_default_log: Optional[pulumi.Input[bool]] = None,
                 firewall_lan_default_log: Optional[pulumi.Input[bool]] = None,
                 firewall_wan_default_log: Optional[pulumi.Input[bool]] = None,
                 multicast_dns_enabled: Optional[pulumi.Input[bool]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = USGArgs.__new__(USGArgs)

            __props__.__dict__["dhcp_relay_servers"] = dhcp_relay_servers
            __props__.__dict__["firewall_guest_default_log"] = firewall_guest_default_log
            __props__.__dict__["firewall_lan_default_log"] = firewall_lan_default_log
            __props__.__dict__["firewall_wan_default_log"] = firewall_wan_default_log
            __props__.__dict__["multicast_dns_enabled"] = multicast_dns_enabled
            __props__.__dict__["site"] = site
        super(USG, __self__).__init__(
            'unifi:setting/uSG:USG',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            dhcp_relay_servers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            firewall_guest_default_log: Optional[pulumi.Input[bool]] = None,
            firewall_lan_default_log: Optional[pulumi.Input[bool]] = None,
            firewall_wan_default_log: Optional[pulumi.Input[bool]] = None,
            multicast_dns_enabled: Optional[pulumi.Input[bool]] = None,
            site: Optional[pulumi.Input[str]] = None) -> 'USG':
        """
        Get an existing USG resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dhcp_relay_servers: The DHCP relay servers.
        :param pulumi.Input[bool] firewall_guest_default_log: Whether the guest firewall log is enabled.
        :param pulumi.Input[bool] firewall_lan_default_log: Whether the LAN firewall log is enabled.
        :param pulumi.Input[bool] firewall_wan_default_log: Whether the WAN firewall log is enabled.
        :param pulumi.Input[bool] multicast_dns_enabled: Whether multicast DNS is enabled.
        :param pulumi.Input[str] site: The name of the site to associate the settings with.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _USGState.__new__(_USGState)

        __props__.__dict__["dhcp_relay_servers"] = dhcp_relay_servers
        __props__.__dict__["firewall_guest_default_log"] = firewall_guest_default_log
        __props__.__dict__["firewall_lan_default_log"] = firewall_lan_default_log
        __props__.__dict__["firewall_wan_default_log"] = firewall_wan_default_log
        __props__.__dict__["multicast_dns_enabled"] = multicast_dns_enabled
        __props__.__dict__["site"] = site
        return USG(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="dhcpRelayServers")
    def dhcp_relay_servers(self) -> pulumi.Output[Sequence[str]]:
        """
        The DHCP relay servers.
        """
        return pulumi.get(self, "dhcp_relay_servers")

    @property
    @pulumi.getter(name="firewallGuestDefaultLog")
    def firewall_guest_default_log(self) -> pulumi.Output[bool]:
        """
        Whether the guest firewall log is enabled.
        """
        return pulumi.get(self, "firewall_guest_default_log")

    @property
    @pulumi.getter(name="firewallLanDefaultLog")
    def firewall_lan_default_log(self) -> pulumi.Output[bool]:
        """
        Whether the LAN firewall log is enabled.
        """
        return pulumi.get(self, "firewall_lan_default_log")

    @property
    @pulumi.getter(name="firewallWanDefaultLog")
    def firewall_wan_default_log(self) -> pulumi.Output[bool]:
        """
        Whether the WAN firewall log is enabled.
        """
        return pulumi.get(self, "firewall_wan_default_log")

    @property
    @pulumi.getter(name="multicastDnsEnabled")
    def multicast_dns_enabled(self) -> pulumi.Output[bool]:
        """
        Whether multicast DNS is enabled.
        """
        return pulumi.get(self, "multicast_dns_enabled")

    @property
    @pulumi.getter
    def site(self) -> pulumi.Output[str]:
        """
        The name of the site to associate the settings with.
        """
        return pulumi.get(self, "site")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['UserArgs', 'User']

@pulumi.input_type
class UserArgs:
    def __init__(__self__, *,
                 mac: pulumi.Input[str],
                 allow_existing: Optional[pulumi.Input[bool]] = None,
                 blocked: Optional[pulumi.Input[bool]] = None,
                 dev_id_override: Optional[pulumi.Input[int]] = None,
                 fixed_ip: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_id: Optional[pulumi.Input[str]] = None,
                 note: Optional[pulumi.Input[str]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 skip_forget_on_destroy: Optional[pulumi.Input[bool]] = None,
                 user_group_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a User resource.
        :param pulumi.Input[str] mac: The MAC address of the user.
        :param pulumi.Input[bool] allow_existing: Specifies whether this resource should just take over control of an existing user. Defaults to `true`.
        :param pulumi.Input[bool] blocked: Specifies whether this user should be blocked from the network.
        :param pulumi.Input[int] dev_id_override: Override the device fingerprint.
        :param pulumi.Input[str] fixed_ip: A fixed IPv4 address for this user.
        :param pulumi.Input[str] name: The name of the user.
        :param pulumi.Input[str] network_id: The network ID for this user.
        :param pulumi.Input[str] note: A note with additional information for the user.
        :param pulumi.Input[str] site: The name of the site to associate the user with.
        :param pulumi.Input[bool] skip_forget_on_destroy: Specifies whether this resource should tell the controller to "forget" the user on destroy. Defaults to `false`.
        :param pulumi.Input[str] user_group_id: The user group ID for the user.
        """
        pulumi.set(__self__, "mac", mac)
        if allow_existing is not None:
            pulumi.set(__self__, "allow_existing", allow_existing)
        if blocked is not None:
            pulumi.set(__self__, "blocked", blocked)
        if dev_id_override is not None:
            pulumi.set(__self__, "dev_id_override", dev_id_override)
        if fixed_ip is not None:
            pulumi.set(__self__, "fixed_ip", fixed_ip)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network_id is not None:
            pulumi.set(__self__, "network_id", network_id)
        if note is not None:
            pulumi.set(__self__, "note", note)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if skip_forget_on_destroy is not None:
            pulumi.set(__self__, "skip_forget_on_destroy", skip_forget_on_destroy)
        if user_group_id is not None:
            pulumi.set(__self__, "user_group_id", user_group_id)

    @property
    @pulumi.getter
    def mac(self) -> pulumi.Input[str]:
        """
        The MAC address of the user.
        """
        return pulumi.get(self, "mac")

    @mac.setter
    def mac(self, value: pulumi.Input[str]):
        pulumi.set(self, "mac", value)

    @property
    @pulumi.getter(name="allowExisting")
    def allow_existing(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether this resource should just take over control of an existing user. Defaults to `true`.
        """
        return pulumi.get(self, "allow_existing")

    @allow_existing.setter
    def allow_existing(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "allow_existing", value)

    @property
    @pulumi.getter
    def blocked(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether this user should be blocked from the network.
        """
        return pulumi.get(self, "blocked")

    @blocked.setter
    def blocked(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "blocked", value)

    @property
    @pulumi.getter(name="devIdOverride")
    def dev_id_override(self) -> Optional[pulumi.Input[int]]:
        """
        Override the device fingerprint.
        """
        return pulumi.get(self, "dev_id_override")

    @dev_id_override.setter
    def dev_id_override(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "dev_id_override", value)

    @property
    @pulumi.getter(name="fixedIp")
    def fixed_ip(self) -> Optional[pulumi.Input[str]]:
        """
        A fixed IPv4 address for this user.
        """
        return pulumi.get(self, "fixed_ip")

    @fixed_ip.setter
    def fixed_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fixed_ip", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the user.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> Optional[pulumi.Input[str]]:
        """
        The network ID for this user.
        """
        return pulumi.get(self, "network_id")

    @network_id.setter
    def network_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "network_id", value)

    @property
    @pulumi.getter
    def note(self) -> Optional[pulumi.Input[str]]:
        """
        A note with additional information for the user.
        """
        return pulumi.get(self, "note")

    @note.setter
    def note(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "note", value)

    @property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the site to associate the user with.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "site", value)

    @property
    @pulumi.getter(name="skipForgetOnDestroy")
    def skip_forget_on_destroy(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether this resource should tell the controller to "forget" the user on destroy. Defaults to `false`.
        """
        return pulumi.get(self, "skip_forget_on_destroy")

    @skip_forget_on_destroy.setter
    def skip_forget_on_destroy(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "skip_forget_on_destroy", value)

    @property
    @pulumi.getter(name="userGroupId")
    def user_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The user group ID for the user.
        """
        return pulumi.get(self, "user_group_id")

    @user_group_id.setter
    def user_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_group_id", value)


@pulumi.input_type
class _UserState:
    def __init__(__self__, *,
                 allow_existing: Optional[pulumi.Input[bool]] = None,
                 blocked: Optional[pulumi.Input[bool]] = None,
                 dev_id_override: Optional[pulumi.Input[int]] = None,
                 fixed_ip: Optional[pulumi.Input[str]] = None,
                 hostname: Optional[pulumi.Input[str]] = None,
                 ip: Optional[pulumi.Input[str]] = None,
                 mac: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_id: Optional[pulumi.Input[str]] = None,
                 note: Optional[pulumi.Input[str]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 skip_forget_on_destroy: Optional[pulumi.Input[bool]] = None,
                 user_group_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering User resources.
        :param pulumi.Input[bool] allow_existing: Specifies whether this resource should just take over control of an existing user. Defaults to `true`.
        :param pulumi.Input[bool] blocked: Specifies whether this user should be blocked from the network.
        :param pulumi.Input[int] dev_id_override: Override the device fingerprint.
        :param pulumi.Input[str] fixed_ip: A fixed IPv4 address for this user.
        :param pulumi.Input[str] hostname: The hostname of the user.
        :param pulumi.Input[str] ip: The IP address of the user.
        :param pulumi.Input[str] mac: The MAC address of the user.
        :param pulumi.Input[str] name: The name of the user.
        :param pulumi.Input[str] network_id: The network ID for this user.
        :param pulumi.Input[str] note: A note with additional information for the user.
        :param pulumi.Input[str] site: The name of the site to associate the user with.
        :param pulumi.Input[bool] skip_forget_on_destroy: Specifies whether this resource should tell the controller to "forget" the user on destroy. Defaults to `false`.
        :param pulumi.Input[str] user_group_id: The user group ID for the user.
        """
        if allow_existing is not None:
            pulumi.set(__self__, "allow_existing", allow_existing)
        if blocked is not None:
            pulumi.set(__self__, "blocked", blocked)
        if dev_id_override is not None:
            pulumi.set(__self__, "dev_id_override", dev_id_override)
        if fixed_ip is not None:
            pulumi.set(__self__, "fixed_ip", fixed_ip)
        if hostname is not None:
            pulumi.set(__self__, "hostname", hostname)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if mac is not None:
            pulumi.set(__self__, "mac", mac)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network_id is not None:
            pulumi.set(__self__, "network_id", network_id)
        if note is not None:
            pulumi.set(__self__, "note", note)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if skip_forget_on_destroy is not None:
            pulumi.set(__self__, "skip_forget_on_destroy", skip_forget_on_destroy)
        if user_group_id is not None:
            pulumi.set(__self__, "user_group_id", user_group_id)

    @property
    @pulumi.getter(name="allowExisting")
    def allow_existing(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether this resource should just take over control of an existing user. Defaults to `true`.
        """
        return pulumi.get(self, "allow_existing")

    @allow_existing.setter
    def allow_existing(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "allow_existing", value)

    @property
    @pulumi.getter
    def blocked(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether this user should be blocked from the network.
        """
        return pulumi.get(self, "blocked")

    @blocked.setter
    def blocked(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "blocked", value)

    @property
    @pulumi.getter(name="devIdOverride")
    def dev_id_override(self) -> Optional[pulumi.Input[int]]:
        """
        Override the device fingerprint.
        """
        return pulumi.get(self, "dev_id_override")

    @dev_id_override.setter
    def dev_id_override(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "dev_id_override", value)

    @property
    @pulumi.getter(name="fixedIp")
    def fixed_ip(self) -> Optional[pulumi.Input[str]]:
        """
        A fixed IPv4 address for this user.
        """
        return pulumi.get(self, "fixed_ip")

    @fixed_ip.setter
    def fixed_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fixed_ip", value)

    @property
    @pulumi.getter
    def hostname(self) -> Optional[pulumi.Input[str]]:
        """
        The hostname of the user.
        """
        return pulumi.get(self, "hostname")

    @hostname.setter
    def hostname(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hostname", value)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[str]]:
        """
        The IP address of the user.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter
    def mac(self) -> Optional[pulumi.Input[str]]:
        """
        The MAC address of the user.
        """
        return pulumi.get(self, "mac")

    @mac.setter
    def mac(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mac", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the user.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> Optional[pulumi.Input[str]]:
        """
        The network ID for this user.
        """
        return pulumi.get(self, "network_id")

    @network_id.setter
    def network_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "network_id", value)

    @property
    @pulumi.getter
    def note(self) -> Optional[pulumi.Input[str]]:
        """
        A note with additional information for the user.
        """
        return pulumi.get(self, "note")

    @note.setter
    def note(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "note", value)

    @property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the site to associate the user with.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "site", value)

    @property
    @pulumi.getter(name="skipForgetOnDestroy")
    def skip_forget_on_destroy(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether this resource should tell the controller to "forget" the user on destroy. Defaults to `false`.
        """
        return pulumi.get(self, "skip_forget_on_destroy")

    @skip_forget_on_destroy.setter
    def skip_forget_on_destroy(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "skip_forget_on_destroy", value)

    @property
    @pulumi.getter(name="userGroupId")
    def user_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The user group ID for the user.
        """
        return pulumi.get(self, "user_group_id")

    @user_group_id.setter
    def user_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_group_id", value)


class User(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_existing: Optional[pulumi.Input[bool]] = None,
                 blocked: Optional[pulumi.Input[bool]] = None,
                 dev_id_override: Optional[pulumi.Input[int]] = None,
                 fixed_ip: Optional[pulumi.Input[str]] = None,
                 mac: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_id: Optional[pulumi.Input[str]] = None,
                 note: Optional[pulumi.Input[str]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 skip_forget_on_destroy: Optional[pulumi.Input[bool]] = None,
                 user_group_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        `iam.User` manages a user (or "client" in the UI) of the network, these are identified by unique MAC addresses.

        Users are created in the controller when observed on the network, so the resource defaults to allowing itself to just take over management of a MAC address, but this can be turned off.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        test = unifi.iam.User("test",
            mac="01:23:45:67:89:AB",
            note="my note",
            fixed_ip="10.0.0.50",
            network_id=unifi_network["my_vlan"]["id"])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] allow_existing: Specifies whether this resource should just take over control of an existing user. Defaults to `true`.
        :param pulumi.Input[bool] blocked: Specifies whether this user should be blocked from the network.
        :param pulumi.Input[int] dev_id_override: Override the device fingerprint.
        :param pulumi.Input[str] fixed_ip: A fixed IPv4 address for this user.
        :param pulumi.Input[str] mac: The MAC address of the user.
        :param pulumi.Input[str] name: The name of the user.
        :param pulumi.Input[str] network_id: The network ID for this user.
        :param pulumi.Input[str] note: A note with additional information for the user.
        :param pulumi.Input[str] site: The name of the site to associate the user with.
        :param pulumi.Input[bool] skip_forget_on_destroy: Specifies whether this resource should tell the controller to "forget" the user on destroy. Defaults to `false`.
        :param pulumi.Input[str] user_group_id: The user group ID for the user.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `iam.User` manages a user (or "client" in the UI) of the network, these are identified by unique MAC addresses.

        Users are created in the controller when observed on the network, so the resource defaults to allowing itself to just take over management of a MAC address, but this can be turned off.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        test = unifi.iam.User("test",
            mac="01:23:45:67:89:AB",
            note="my note",
            fixed_ip="10.0.0.50",
            network_id=unifi_network["my_vlan"]["id"])
        ```

        :param str resource_name: The name of the resource.
        :param UserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_existing: Optional[pulumi.Input[bool]] = None,
                 blocked: Optional[pulumi.Input[bool]] = None,
                 dev_id_override: Optional[pulumi.Input[int]] = None,
                 fixed_ip: Optional[pulumi.Input[str]] = None,
                 mac: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_id: Optional[pulumi.Input[str]] = None,
                 note: Optional[pulumi.Input[str]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 skip_forget_on_destroy: Optional[pulumi.Input[bool]] = None,
                 user_group_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserArgs.__new__(UserArgs)

            __props__.__dict__["allow_existing"] = allow_existing
            __props__.__dict__["blocked"] = blocked
            __props__.__dict__["dev_id_override"] = dev_id_override
            __props__.__dict__["fixed_ip"] = fixed_ip
            if mac is None and not opts.urn:
                raise TypeError("Missing required property 'mac'")
            __props__.__dict__["mac"] = mac
            __props__.__dict__["name"] = name
            __props__.__dict__["network_id"] = network_id
            __props__.__dict__["note"] = note
            __props__.__dict__["site"] = site
            __props__.__dict__["skip_forget_on_destroy"] = skip_forget_on_destroy
            __props__.__dict__["user_group_id"] = user_group_id
            __props__.__dict__["hostname"] = None
            __props__.__dict__["ip"] = None
        super(User, __self__).__init__(
            'unifi:iam/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allow_existing: Optional[pulumi.Input[bool]] = None,
            blocked: Optional[pulumi.Input[bool]] = None,
            dev_id_override: Optional[pulumi.Input[int]] = None,
            fixed_ip: Optional[pulumi.Input[str]] = None,
            hostname: Optional[pulumi.Input[str]] = None,
            ip: Optional[pulumi.Input[str]] = None,
            mac: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            network_id: Optional[pulumi.Input[str]] = None,
            note: Optional[pulumi.Input[str]] = None,
            site: Optional[pulumi.Input[str]] = None,
            skip_forget_on_destroy: Optional[pulumi.Input[bool]] = None,
            user_group_id: Optional[pulumi.Input[str]] = None) -> 'User':
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] allow_existing: Specifies whether this resource should just take over control of an existing user. Defaults to `true`.
        :param pulumi.Input[bool] blocked: Specifies whether this user should be blocked from the network.
        :param pulumi.Input[int] dev_id_override: Override the device fingerprint.
        :param pulumi.Input[str] fixed_ip: A fixed IPv4 address for this user.
        :param pulumi.Input[str] hostname: The hostname of the user.
        :param pulumi.Input[str] ip: The IP address of the user.
        :param pulumi.Input[str] mac: The MAC address of the user.
        :param pulumi.Input[str] name: The name of the user.
        :param pulumi.Input[str] network_id: The network ID for this user.
        :param pulumi.Input[str] note: A note with additional information for the user.
        :param pulumi.Input[str] site: The name of the site to associate the user with.
        :param pulumi.Input[bool] skip_forget_on_destroy: Specifies whether this resource should tell the controller to "forget" the user on destroy. Defaults to `false`.
        :param pulumi.Input[str] user_group_id: The user group ID for the user.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserState.__new__(_UserState)

        __props__.__dict__["allow_existing"] = allow_existing
        __props__.__dict__["blocked"] = blocked
        __props__.__dict__["dev_id_override"] = dev_id_override
        __props__.__dict__["fixed_ip"] = fixed_ip
        __props__.__dict__["hostname"] = hostname
        __props__.__dict__["ip"] = ip
        __props__.__dict__["mac"] = mac
        __props__.__dict__["name"] = name
        __props__.__dict__["network_id"] = network_id
        __props__.__dict__["note"] = note
        __props__.__dict__["site"] = site
        __props__.__dict__["skip_forget_on_destroy"] = skip_forget_on_destroy
        __props__.__dict__["user_group_id"] = user_group_id
        return User(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allowExisting")
    def allow_existing(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether this resource should just take over control of an existing user. Defaults to `true`.
        """
        return pulumi.get(self, "allow_existing")

    @property
    @pulumi.getter
    def blocked(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether this user should be blocked from the network.
        """
        return pulumi.get(self, "blocked")

    @property
    @pulumi.getter(name="devIdOverride")
    def dev_id_override(self) -> pulumi.Output[Optional[int]]:
        """
        Override the device fingerprint.
        """
        return pulumi.get(self, "dev_id_override")

    @property
    @pulumi.getter(name="fixedIp")
    def fixed_ip(self) -> pulumi.Output[Optional[str]]:
        """
        A fixed IPv4 address for this user.
        """
        return pulumi.get(self, "fixed_ip")

    @property
    @pulumi.getter
    def hostname(self) -> pulumi.Output[str]:
        """
        The hostname of the user.
        """
        return pulumi.get(self, "hostname")

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Output[str]:
        """
        The IP address of the user.
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter
    def mac(self) -> pulumi.Output[str]:
        """
        The MAC address of the user.
        """
        return pulumi.get(self, "mac")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the user.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> pulumi.Output[Optional[str]]:
        """
        The network ID for this user.
        """
        return pulumi.get(self, "network_id")

    @property
    @pulumi.getter
    def note(self) -> pulumi.Output[Optional[str]]:
        """
        A note with additional information for the user.
        """
        return pulumi.get(self, "note")

    @property
    @pulumi.getter
    def site(self) -> pulumi.Output[str]:
        """
        The name of the site to associate the user with.
        """
        return pulumi.get(self, "site")

    @property
    @pulumi.getter(name="skipForgetOnDestroy")
    def skip_forget_on_destroy(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether this resource should tell the controller to "forget" the user on destroy. Defaults to `false`.
        """
        return pulumi.get(self, "skip_forget_on_destroy")

    @property
    @pulumi.getter(name="userGroupId")
    def user_group_id(self) -> pulumi.Output[Optional[str]]:
        """
        The user group ID for the user.
        """
        return pulumi.get(self, "user_group_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'DevicePortOverrideArgs',
    'WlanScheduleArgs',
]

@pulumi.input_type
class DevicePortOverrideArgs:
    def __init__(__self__, *,
                 number: pulumi.Input[int],
                 name: Optional[pulumi.Input[str]] = None,
                 port_profile_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[int] number: Switch port number.
        :param pulumi.Input[str] name: Human-readable name of the port.
        :param pulumi.Input[str] port_profile_id: ID of the Port Profile used on this port.
        """
        pulumi.set(__self__, "number", number)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port_profile_id is not None:
            pulumi.set(__self__, "port_profile_id", port_profile_id)

    @property
    @pulumi.getter
    def number(self) -> pulumi.Input[int]:
        """
        Switch port number.
        """
        return pulumi.get(self, "number")

    @number.setter
    def number(self, value: pulumi.Input[int]):
        pulumi.set(self, "number", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Human-readable name of the port.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="portProfileId")
    def port_profile_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the Port Profile used on this port.
        """
        return pulumi.get(self, "port_profile_id")

    @port_profile_id.setter
    def port_profile_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "port_profile_id", value)


@pulumi.input_type
class WlanScheduleArgs:
    def __init__(__self__, *,
                 block_end: pulumi.Input[str],
                 block_start: pulumi.Input[str],
                 day_of_week: pulumi.Input[str]):
        """
        :param pulumi.Input[str] block_end: Time of day to end the block.
        :param pulumi.Input[str] block_start: Time of day to start the block.
        :param pulumi.Input[str] day_of_week: Day of week for the block. Valid values are `sun`, `mon`, `tue`, `wed`, `thu`, `fri`, `sat`.
        """
        pulumi.set(__self__, "block_end", block_end)
        pulumi.set(__self__, "block_start", block_start)
        pulumi.set(__self__, "day_of_week", day_of_week)

    @property
    @pulumi.getter(name="blockEnd")
    def block_end(self) -> pulumi.Input[str]:
        """
        Time of day to end the block.
        """
        return pulumi.get(self, "block_end")

    @block_end.setter
    def block_end(self, value: pulumi.Input[str]):
        pulumi.set(self, "block_end", value)

    @property
    @pulumi.getter(name="blockStart")
    def block_start(self) -> pulumi.Input[str]:
        """
        Time of day to start the block.
        """
        return pulumi.get(self, "block_start")

    @block_start.setter
    def block_start(self, value: pulumi.Input[str]):
        pulumi.set(self, "block_start", value)

    @property
    @pulumi.getter(name="dayOfWeek")
    def day_of_week(self) -> pulumi.Input[str]:
        """
        Day of week for the block. Valid values are `sun`, `mon`, `tue`, `wed`, `thu`, `fri`, `sat`.
        """
        return pulumi.get(self, "day_of_week")

    @day_of_week.setter
    def day_of_week(self, value: pulumi.Input[str]):
        pulumi.set(self, "day_of_week", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'MgmtSshKeyArgs',
]

@pulumi.input_type
class MgmtSshKeyArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 type: pulumi.Input[str],
                 comment: Optional[pulumi.Input[str]] = None,
                 key: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] name: Name of SSH key.
        :param pulumi.Input[str] type: Type of SSH key, e.g. ssh-rsa.
        :param pulumi.Input[str] comment: Comment.
        :param pulumi.Input[str] key: Public SSH key.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "type", type)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if key is not None:
            pulumi.set(__self__, "key", key)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Name of SSH key.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        Type of SSH key, e.g. ssh-rsa.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        Comment.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[str]]:
        """
        Public SSH key.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DeviceArgs', 'Device']

@pulumi.input_type
class DeviceArgs:
    def __init__(__self__, *,
                 mac: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 port_overrides: Optional[pulumi.Input[Sequence[pulumi.Input['DevicePortOverrideArgs']]]] = None,
                 site: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Device resource.
        :param pulumi.Input[str] mac: The MAC address of the device. This can be specified so that the provider can take control of a device (since devices are created through adoption).
        :param pulumi.Input[str] name: The name of the device.
        :param pulumi.Input[Sequence[pulumi.Input['DevicePortOverrideArgs']]] port_overrides: Settings overrides for specific switch ports.
        :param pulumi.Input[str] site: The name of the site to associate the device with.
        """
        if mac is not None:
            pulumi.set(__self__, "mac", mac)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port_overrides is not None:
            pulumi.set(__self__, "port_overrides", port_overrides)
        if site is not None:
            pulumi.set(__self__, "site", site)

    @property
    @pulumi.getter
    def mac(self) -> Optional[pulumi.Input[str]]:
        """
        The MAC address of the device. This can be specified so that the provider can take control of a device (since devices are created through adoption).
        """
        return pulumi.get(self, "mac")

    @mac.setter
    def mac(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mac", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the device.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="portOverrides")
    def port_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DevicePortOverrideArgs']]]]:
        """
        Settings overrides for specific switch ports.
        """
        return pulumi.get(self, "port_overrides")

    @port_overrides.setter
    def port_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DevicePortOverrideArgs']]]]):
        pulumi.set(self, "port_overrides", value)

    @property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the site to associate the device with.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "site", value)


@pulumi.input_type
class _DeviceState:
    def __init__(__self__, *,
                 disabled: Optional[pulumi.Input[bool]] = None,
                 mac: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 port_overrides: Optional[pulumi.Input[Sequence[pulumi.Input['DevicePortOverrideArgs']]]] = None,
                 site: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Device resources.
        :param pulumi.Input[bool] disabled: Specifies whether this device should be disabled.
        :param pulumi.Input[str] mac: The MAC address of the device. This can be specified so that the provider can take control of a device (since devices are created through adoption).
        :param pulumi.Input[str] name: The name of the device.
        :param pulumi.Input[Sequence[pulumi.Input['DevicePortOverrideArgs']]] port_overrides: Settings overrides for specific switch ports.
        :param pulumi.Input[str] site: The name of the site to associate the device with.
        """
        if disabled is not None:
            pulumi.set(__self__, "disabled", disabled)
        if mac is not None:
            pulumi.set(__self__, "mac", mac)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port_overrides is not None:
            pulumi.set(__self__, "port_overrides", port_overrides)
        if site is not None:
            pulumi.set(__self__, "site", site)

    @property
    @pulumi.getter
    def disabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether this device should be disabled.
        """
        return pulumi.get(self, "disabled")

    @disabled.setter
    def disabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "disabled", value)

    @property
    @pulumi.getter
    def mac(self) -> Optional[pulumi.Input[str]]:
        """
        The MAC address of the device. This can be specified so that the provider can take control of a device (since devices are created through adoption).
        """
        return pulumi.get(self, "mac")

    @mac.setter
    def mac(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mac", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the device.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="portOverrides")
    def port_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DevicePortOverrideArgs']]]]:
        """
        Settings overrides for specific switch ports.
        """
        return pulumi.get(self, "port_overrides")

    @port_overrides.setter
    def port_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DevicePortOverrideArgs']]]]):
        pulumi.set(self, "port_overrides", value)

    @property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the site to associate the device with.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "site", value)


class Device(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 mac: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 port_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DevicePortOverrideArgs']]]]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_unifi as unifi
        import pulumiverse_unifi as unifi

        disabled = unifi.port.get_profile(name="Disabled")
        poe = unifi.port.Profile("poe",
            forward="customize",
            native_networkconf_id=var["native_network_id"],
            tagged_networkconf_ids=[var["some_vlan_network_id"]],
            poe_mode="auto")
        us24_poe = unifi.Device("us24Poe",
            mac="01:23:45:67:89:AB",
            port_overrides=[
                unifi.DevicePortOverrideArgs(
                    number=1,
                    name="port w/ poe",
                    port_profile_id=poe.id,
                ),
                unifi.DevicePortOverrideArgs(
                    number=2,
                    name="disabled",
                    port_profile_id=disabled.id,
                ),
            ])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] mac: The MAC address of the device. This can be specified so that the provider can take control of a device (since devices are created through adoption).
        :param pulumi.Input[str] name: The name of the device.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DevicePortOverrideArgs']]]] port_overrides: Settings overrides for specific switch ports.
        :param pulumi.Input[str] site: The name of the site to associate the device with.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[DeviceArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_unifi as unifi
        import pulumiverse_unifi as unifi

        disabled = unifi.port.get_profile(name="Disabled")
        poe = unifi.port.Profile("poe",
            forward="customize",
            native_networkconf_id=var["native_network_id"],
            tagged_networkconf_ids=[var["some_vlan_network_id"]],
            poe_mode="auto")
        us24_poe = unifi.Device("us24Poe",
            mac="01:23:45:67:89:AB",
            port_overrides=[
                unifi.DevicePortOverrideArgs(
                    number=1,
                    name="port w/ poe",
                    port_profile_id=poe.id,
                ),
                unifi.DevicePortOverrideArgs(
                    number=2,
                    name="disabled",
                    port_profile_id=disabled.id,
                ),
            ])
        ```

        :param str resource_name: The name of the resource.
        :param DeviceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DeviceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 mac: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 port_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DevicePortOverrideArgs']]]]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DeviceArgs.__new__(DeviceArgs)

            __props__.__dict__["mac"] = mac
            __props__.__dict__["name"] = name
            __props__.__dict__["port_overrides"] = port_overrides
            __props__.__dict__["site"] = site
            __props__.__dict__["disabled"] = None
        super(Device, __self__).__init__(
            'unifi:index/device:Device',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            disabled: Optional[pulumi.Input[bool]] = None,
            mac: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            port_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DevicePortOverrideArgs']]]]] = None,
            site: Optional[pulumi.Input[str]] = None) -> 'Device':
        """
        Get an existing Device resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] disabled: Specifies whether this device should be disabled.
        :param pulumi.Input[str] mac: The MAC address of the device. This can be specified so that the provider can take control of a device (since devices are created through adoption).
        :param pulumi.Input[str] name: The name of the device.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DevicePortOverrideArgs']]]] port_overrides: Settings overrides for specific switch ports.
        :param pulumi.Input[str] site: The name of the site to associate the device with.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DeviceState.__new__(_DeviceState)

        __props__.__dict__["disabled"] = disabled
        __props__.__dict__["mac"] = mac
        __props__.__dict__["name"] = name
        __props__.__dict__["port_overrides"] = port_overrides
        __props__.__dict__["site"] = site
        return Device(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def disabled(self) -> pulumi.Output[bool]:
        """
        Specifies whether this device should be disabled.
        """
        return pulumi.get(self, "disabled")

    @property
    @pulumi.getter
    def mac(self) -> pulumi.Output[str]:
        """
        The MAC address of the device. This can be specified so that the provider can take control of a device (since devices are created through adoption).
        """
        return pulumi.get(self, "mac")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the device.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="portOverrides")
    def port_overrides(self) -> pulumi.Output[Optional[Sequence['outputs.DevicePortOverride']]]:
        """
        Settings overrides for specific switch ports.
        """
        return pulumi.get(self, "port_overrides")

    @property
    @pulumi.getter
    def site(self) -> pulumi.Output[str]:
        """
        The name of the site to associate the device with.
        """
        return pulumi.get(self, "site")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['DynamicDNSArgs', 'DynamicDNS']

@pulumi.input_type
class DynamicDNSArgs:
    def __init__(__self__, *,
                 host_name: pulumi.Input[str],
                 service: pulumi.Input[str],
                 interface: Optional[pulumi.Input[str]] = None,
                 login: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 server: Optional[pulumi.Input[str]] = None,
                 site: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a DynamicDNS resource.
        :param pulumi.Input[str] host_name: The host name to update in the dynamic DNS service.
        :param pulumi.Input[str] service: The Dynamic DNS service provider, various values are supported (for example `dyndns`, etc.).
        :param pulumi.Input[str] interface: The interface for the dynamic DNS. Can be `wan` or `wan2`. Defaults to `wan`.
        :param pulumi.Input[str] login: The server for the dynamic DNS service.
        :param pulumi.Input[str] password: The server for the dynamic DNS service.
        :param pulumi.Input[str] server: The server for the dynamic DNS service.
        :param pulumi.Input[str] site: The name of the site to associate the dynamic DNS with.
        """
        pulumi.set(__self__, "host_name", host_name)
        pulumi.set(__self__, "service", service)
        if interface is not None:
            pulumi.set(__self__, "interface", interface)
        if login is not None:
            pulumi.set(__self__, "login", login)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if server is not None:
            pulumi.set(__self__, "server", server)
        if site is not None:
            pulumi.set(__self__, "site", site)

    @property
    @pulumi.getter(name="hostName")
    def host_name(self) -> pulumi.Input[str]:
        """
        The host name to update in the dynamic DNS service.
        """
        return pulumi.get(self, "host_name")

    @host_name.setter
    def host_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "host_name", value)

    @property
    @pulumi.getter
    def service(self) -> pulumi.Input[str]:
        """
        The Dynamic DNS service provider, various values are supported (for example `dyndns`, etc.).
        """
        return pulumi.get(self, "service")

    @service.setter
    def service(self, value: pulumi.Input[str]):
        pulumi.set(self, "service", value)

    @property
    @pulumi.getter
    def interface(self) -> Optional[pulumi.Input[str]]:
        """
        The interface for the dynamic DNS. Can be `wan` or `wan2`. Defaults to `wan`.
        """
        return pulumi.get(self, "interface")

    @interface.setter
    def interface(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "interface", value)

    @property
    @pulumi.getter
    def login(self) -> Optional[pulumi.Input[str]]:
        """
        The server for the dynamic DNS service.
        """
        return pulumi.get(self, "login")

    @login.setter
    def login(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "login", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        The server for the dynamic DNS service.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def server(self) -> Optional[pulumi.Input[str]]:
        """
        The server for the dynamic DNS service.
        """
        return pulumi.get(self, "server")

    @server.setter
    def server(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "server", value)

    @property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the site to associate the dynamic DNS with.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "site", value)


@pulumi.input_type
class _DynamicDNSState:
    def __init__(__self__, *,
                 host_name: Optional[pulumi.Input[str]] = None,
                 interface: Optional[pulumi.Input[str]] = None,
                 login: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 server: Optional[pulumi.Input[str]] = None,
                 service: Optional[pulumi.Input[str]] = None,
                 site: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering DynamicDNS resources.
        :param pulumi.Input[str] host_name: The host name to update in the dynamic DNS service.
        :param pulumi.Input[str] interface: The interface for the dynamic DNS. Can be `wan` or `wan2`. Defaults to `wan`.
        :param pulumi.Input[str] login: The server for the dynamic DNS service.
        :param pulumi.Input[str] password: The server for the dynamic DNS service.
        :param pulumi.Input[str] server: The server for the dynamic DNS service.
        :param pulumi.Input[str] service: The Dynamic DNS service provider, various values are supported (for example `dyndns`, etc.).
        :param pulumi.Input[str] site: The name of the site to associate the dynamic DNS with.
        """
        if host_name is not None:
            pulumi.set(__self__, "host_name", host_name)
        if interface is not None:
            pulumi.set(__self__, "interface", interface)
        if login is not None:
            pulumi.set(__self__, "login", login)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if server is not None:
            pulumi.set(__self__, "server", server)
        if service is not None:
            pulumi.set(__self__, "service", service)
        if site is not None:
            pulumi.set(__self__, "site", site)

    @property
    @pulumi.getter(name="hostName")
    def host_name(self) -> Optional[pulumi.Input[str]]:
        """
        The host name to update in the dynamic DNS service.
        """
        return pulumi.get(self, "host_name")

    @host_name.setter
    def host_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "host_name", value)

    @property
    @pulumi.getter
    def interface(self) -> Optional[pulumi.Input[str]]:
        """
        The interface for the dynamic DNS. Can be `wan` or `wan2`. Defaults to `wan`.
        """
        return pulumi.get(self, "interface")

    @interface.setter
    def interface(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "interface", value)

    @property
    @pulumi.getter
    def login(self) -> Optional[pulumi.Input[str]]:
        """
        The server for the dynamic DNS service.
        """
        return pulumi.get(self, "login")

    @login.setter
    def login(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "login", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        The server for the dynamic DNS service.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def server(self) -> Optional[pulumi.Input[str]]:
        """
        The server for the dynamic DNS service.
        """
        return pulumi.get(self, "server")

    @server.setter
    def server(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "server", value)

    @property
    @pulumi.getter
    def service(self) -> Optional[pulumi.Input[str]]:
        """
        The Dynamic DNS service provider, various values are supported (for example `dyndns`, etc.).
        """
        return pulumi.get(self, "service")

    @service.setter
    def service(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service", value)

    @property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the site to associate the dynamic DNS with.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "site", value)


class DynamicDNS(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 host_name: Optional[pulumi.Input[str]] = None,
                 interface: Optional[pulumi.Input[str]] = None,
                 login: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 server: Optional[pulumi.Input[str]] = None,
                 service: Optional[pulumi.Input[str]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        `DynamicDNS` manages dynamic DNS settings for different providers.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        test = unifi.DynamicDNS("test",
            service="dyndns",
            host_name="my-network.example.com",
            server="domains.google.com",
            login=var["dns_login"],
            password=var["dns_password"])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] host_name: The host name to update in the dynamic DNS service.
        :param pulumi.Input[str] interface: The interface for the dynamic DNS. Can be `wan` or `wan2`. Defaults to `wan`.
        :param pulumi.Input[str] login: The server for the dynamic DNS service.
        :param pulumi.Input[str] password: The server for the dynamic DNS service.
        :param pulumi.Input[str] server: The server for the dynamic DNS service.
        :param pulumi.Input[str] service: The Dynamic DNS service provider, various values are supported (for example `dyndns`, etc.).
        :param pulumi.Input[str] site: The name of the site to associate the dynamic DNS with.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DynamicDNSArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `DynamicDNS` manages dynamic DNS settings for different providers.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        test = unifi.DynamicDNS("test",
            service="dyndns",
            host_name="my-network.example.com",
            server="domains.google.com",
            login=var["dns_login"],
            password=var["dns_password"])
        ```

        :param str resource_name: The name of the resource.
        :param DynamicDNSArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DynamicDNSArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 host_name: Optional[pulumi.Input[str]] = None,
                 interface: Optional[pulumi.Input[str]] = None,
                 login: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 server: Optional[pulumi.Input[str]] = None,
                 service: Optional[pulumi.Input[str]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DynamicDNSArgs.__new__(DynamicDNSArgs)

            if host_name is None and not opts.urn:
                raise TypeError("Missing required property 'host_name'")
            __props__.__dict__["host_name"] = host_name
            __props__.__dict__["interface"] = interface
            __props__.__dict__["login"] = login
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            __props__.__dict__["server"] = server
            if service is None and not opts.urn:
                raise TypeError("Missing required property 'service'")
            __props__.__dict__["service"] = service
            __props__.__dict__["site"] = site
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(DynamicDNS, __self__).__init__(
            'unifi:index/dynamicDNS:DynamicDNS',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            host_name: Optional[pulumi.Input[str]] = None,
            interface: Optional[pulumi.Input[str]] = None,
            login: Optional[pulumi.Input[str]] = None,
            password: Optional[pulumi.Input[str]] = None,
            server: Optional[pulumi.Input[str]] = None,
            service: Optional[pulumi.Input[str]] = None,
            site: Optional[pulumi.Input[str]] = None) -> 'DynamicDNS':
        """
        Get an existing DynamicDNS resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] host_name: The host name to update in the dynamic DNS service.
        :param pulumi.Input[str] interface: The interface for the dynamic DNS. Can be `wan` or `wan2`. Defaults to `wan`.
        :param pulumi.Input[str] login: The server for the dynamic DNS service.
        :param pulumi.Input[str] password: The server for the dynamic DNS service.
        :param pulumi.Input[str] server: The server for the dynamic DNS service.
        :param pulumi.Input[str] service: The Dynamic DNS service provider, various values are supported (for example `dyndns`, etc.).
        :param pulumi.Input[str] site: The name of the site to associate the dynamic DNS with.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DynamicDNSState.__new__(_DynamicDNSState)

        __props__.__dict__["host_name"] = host_name
        __props__.__dict__["interface"] = interface
        __props__.__dict__["login"] = login
        __props__.__dict__["password"] = password
        __props__.__dict__["server"] = server
        __props__.__dict__["service"] = service
        __props__.__dict__["site"] = site
        return DynamicDNS(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="hostName")
    def host_name(self) -> pulumi.Output[str]:
        """
        The host name to update in the dynamic DNS service.
        """
        return pulumi.get(self, "host_name")

    @property
    @pulumi.getter
    def interface(self) -> pulumi.Output[Optional[str]]:
        """
        The interface for the dynamic DNS. Can be `wan` or `wan2`. Defaults to `wan`.
        """
        return pulumi.get(self, "interface")

    @property
    @pulumi.getter
    def login(self) -> pulumi.Output[Optional[str]]:
        """
        The server for the dynamic DNS service.
        """
        return pulumi.get(self, "login")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional[str]]:
        """
        The server for the dynamic DNS service.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def server(self) -> pulumi.Output[Optional[str]]:
        """
        The server for the dynamic DNS service.
        """
        return pulumi.get(self, "server")

    @property
    @pulumi.getter
    def service(self) -> pulumi.Output[str]:
        """
        The Dynamic DNS service provider, various values are supported (for example `dyndns`, etc.).
        """
        return pulumi.get(self, "service")

    @property
    @pulumi.getter
    def site(self) -> pulumi.Output[str]:
        """
        The name of the site to associate the dynamic DNS with.
        """
        return pulumi.get(self, "site")

